import React, { useState, useEffect } from 'react';
import Start from './components/Start/Start';
import Second from './components/Second/Second';
import Tinder from './components/Tinder/Tinder';
import Main from './components/Main/Main';
import City from './components/City/City';
import axios from 'axios';
import './App.css';

function App() {
  const [buttonValue, setButtonValue] = useState("");
  const [isHidden, setIsHidden] = useState(false);
  const [cardInfo, setCardInfo] = useState([]);
  const [userData, setUserData] = useState({});

  const handleButtonValue = (value) => {
    setIsHidden(true);
    setTimeout(() => {
      setIsHidden(false);
      setButtonValue(value);
    }, 300);
  };

  useEffect(() => {
    const fetchData = () => {
      axios.get('https://easytravel.zetcraft.ru/v1/GetAllCards')
        .then(response => {
          setCardInfo(response.data);
        })
        .catch(error => {
          console.error('Error fetching data:', error);
        });
    }
    fetchData();
  }, []);

  useEffect(() => {
    // Загрузка userData из localStorage при монтировании компонента
    const savedUserData = JSON.parse(localStorage.getItem('userData'));
    if (savedUserData) {
      setUserData(savedUserData);
    }
  }, []);

  useEffect(() => {
    // Сохранение userData в localStorage при изменении
    localStorage.setItem('userData', JSON.stringify(userData));
    console.log(userData);
  }, [userData]);

  let content = null;
  switch (buttonValue) {
    case '/second':
      content = <Second getValue={handleButtonValue}setUserData={setUserData} />
      break;
    case '/tinder':
      content = <Tinder getValue={handleButtonValue} cardInfo={cardInfo} userData={userData} setUserData={setUserData} />
      break;
    case '/main':
      content = <Main />
      break;
    case '/city':
      content = <City getValue={handleButtonValue} setUserData={setUserData} />
      break;
    default:
      content = <Start getValue={handleButtonValue} userData={userData} setUserData={setUserData} />
  }

  const arrayLength = userData.unique ? userData.unique.length : 0;

  return (
    <div className={`App ${isHidden ? 'hidden' : ''}`}>
      {arrayLength !== 0 ? <Main userData={userData}/> : content}
    </div>
  );
}

export default App;
